PredefinedEncoding

Enum PredefinedEncoding 

pub enum PredefinedEncoding {
    Standard,
    Expert,
    IsoLatin1,
}
Predefined encodings for Adobe CFF and Type1 fonts.

Encodings map character codes to glyph names.

See https://adobe-type-tools.github.io/font-tech-notes/pdfs/5176.CFF.pdf#page=37.

Variants



Standard



Expert



IsoLatin1

Implementations

Source

impl PredefinedEncoding

pub fn name(&self, code: u8) -> &'static str

Converts a character code to the associated glyph name according to the selected encoding.

pub fn sid(&self, code: u8) -> Option<Sid>

Returns the string id for the given character code.